@@ -1,6 +1,6 @@
 /*
  * yauap - A simple commandline frontend for GStreamer 
- * Copyright (c) 2006 Sascha Sommer <ssommer@suse.de>
+ * Copyright (c) 2006 - 2008 Sascha Sommer <ssommer@suse.de>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,6 +23,7 @@
 #include <string.h>
 #include <unistd.h>
 #include <gst/gst.h>
+#include <gst/pbutils/missing-plugins.h>
 
 #include "yauap.h"
 
@@ -48,8 +49,8 @@ typedef struct yauap_priv_s {
 #define SAMPLE_BUFFER_SIZE (SCOPE_SIZE * 1000)
     unsigned char sample_buffer[SAMPLE_BUFFER_SIZE];
     unsigned int sample_scale;
-    unsigned int write_pos;
-    unsigned int read_pos;
+    int write_pos;
+    int read_pos;
     guint64 sample_timestamp;
 } yauap_priv_t;
 
@@ -363,6 +364,27 @@ static gboolean gstreamer_callback(GstBus *bus,GstMessage *msg,gpointer    data)
             player_stop(player);
             signal_frontend(player,SIGNAL_EOS,"end of stream");
             break;
+	case GST_MESSAGE_ELEMENT:
+	    if(gst_is_missing_plugin_message(msg)){
+	        char* desc = gst_missing_plugin_message_get_description(msg);
+	        char* installer_details = gst_missing_plugin_message_get_installer_detail(msg);
+		size_t msg_len = strlen(desc) + strlen(installer_details) + strlen("plugin ") + strlen(" is missing (") + 2;
+		char* text = malloc(msg_len);
+		snprintf(text,msg_len,"plugin %s is missing (%s)",desc,installer_details);
+		if(desc)
+		    g_free(desc);
+		if(installer_details)
+		    g_free(installer_details);
+		printf("\nError: %s\n",text);
+		signal_frontend(player,SIGNAL_ERROR,text); 
+		free(text);
+
+	        signal_frontend(player,SIGNAL_EOS,"unable to continue");
+
+       		player_stop(player);
+
+	    }
+	    break;
         case GST_MESSAGE_ERROR: {
             gchar *debug;
             GError *err;
@@ -759,7 +781,7 @@ int main(int argc, char* argv[]){
     int i;
     int run=1;
     
-    printf("yauap " VERSION " (C) 2006-2007 Sascha Sommer <ssommer@suse.de>\n");
+    printf("yauap " VERSION " (C) 2006-2008 Sascha Sommer <ssommer@suse.de>\n");
 
 
     /* set function pointers */
